WooCart class

Constructors

WooCart({String? currency, int? itemCount, List<WooCartItems>? items, bool? needsShipping, String? totalPrice, int? totalWeight})
WooCart.fromJson(Map<String, dynamic> json)

Properties

currency ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
itemCount ↔ int?
getter/setter pair
items ↔ List<WooCartItems>?
getter/setter pair
needsShipping ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalPrice ↔ String?
getter/setter pair
totalWeight ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited