WooCustomer class

Constructors

WooCustomer({int? id, String? dateCreated, String? dateCreatedGmt, String? dateModified, String? dateModifiedGmt, String? email, String? firstName, String? lastName, String? role, String? username, String? password, Billing? billing, Shipping? shipping, bool? isPayingCustomer, String? avatarUrl, List<WooCustomerMetaData>? metaData, Links? links})
WooCustomer.fromJson(Map<String, dynamic> json)

Properties

avatarUrl ↔ String?
getter/setter pair
billing ↔ Billing?
getter/setter pair
dateCreated ↔ String?
getter/setter pair
dateCreatedGmt ↔ String?
getter/setter pair
dateModified ↔ String?
getter/setter pair
dateModifiedGmt ↔ String?
getter/setter pair
email ↔ String?
getter/setter pair
firstName ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
id ↔ int?
getter/setter pair
isPayingCustomer ↔ bool?
getter/setter pair
lastName ↔ String?
getter/setter pair
getter/setter pair
metaData ↔ List<WooCustomerMetaData>?
getter/setter pair
password ↔ String?
getter/setter pair
role ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shipping ↔ Shipping?
getter/setter pair
username ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override