WooProductVariation class

Constructors

WooProductVariation(int? id, DateTime? dateCreated, DateTime? dateCreatedGmt, DateTime? dateModified, DateTime? dateModifiedGmt, String? description, String? permalink, String? sku, String? price, List<WooProductVariationAttribute> attributes, String? regularPrice, String? salePrice, DateTime? dateOnSaleFrom, DateTime? dateOnSaleFromGmt, DateTime? dateOnSaleTo, DateTime? dateOnSaleToGmt, bool? onSale, String? status, bool? purchasable, bool? virtual, bool? downloadable, List<WooProductVariationDownload> downloads, int? downloadLimit, int? downloadExpiry, String? taxStatus, String? taxClass, bool? manageStock, int? stockQuantity, String? stockStatus, String? backorders, bool? backordersAllowed, bool? backordered, String? weight, String? shippingClass, int? shippingClassId, int? menuOrder, WooProductVariationDimension dimensions, List<WooProductVariationMetaData> metaData, WooProductVariationImage? image)
WooProductVariation.fromJson(Map<String, dynamic> json)

Properties

attributes ↔ List<WooProductVariationAttribute>
getter/setter pair
backordered ↔ bool?
getter/setter pair
backorders ↔ String?
getter/setter pair
backordersAllowed ↔ bool?
getter/setter pair
dateCreated ↔ DateTime?
getter/setter pair
dateCreatedGmt ↔ DateTime?
getter/setter pair
dateModified ↔ DateTime?
getter/setter pair
dateModifiedGmt ↔ DateTime?
getter/setter pair
dateOnSaleFrom ↔ DateTime?
getter/setter pair
dateOnSaleFromGmt ↔ DateTime?
getter/setter pair
dateOnSaleTo ↔ DateTime?
getter/setter pair
dateOnSaleToGmt ↔ DateTime?
getter/setter pair
description ↔ String?
getter/setter pair
dimensions ↔ WooProductVariationDimension
getter/setter pair
downloadable ↔ bool?
getter/setter pair
downloadExpiry ↔ int?
getter/setter pair
downloadLimit ↔ int?
getter/setter pair
downloads ↔ List<WooProductVariationDownload>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
getter/setter pair
image ↔ WooProductVariationImage?
getter/setter pair
manageStock ↔ bool?
getter/setter pair
getter/setter pair
metaData ↔ List<WooProductVariationMetaData>
getter/setter pair
onSale ↔ bool?
getter/setter pair
getter/setter pair
price ↔ String?
getter/setter pair
purchasable ↔ bool?
getter/setter pair
regularPrice ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
salePrice ↔ String?
getter/setter pair
shippingClass ↔ String?
getter/setter pair
shippingClassId ↔ int?
getter/setter pair
sku ↔ String?
getter/setter pair
status ↔ String?
getter/setter pair
stockQuantity ↔ int?
getter/setter pair
stockStatus ↔ String?
getter/setter pair
taxClass ↔ String?
getter/setter pair
taxStatus ↔ String?
getter/setter pair
virtual ↔ bool?
getter/setter pair
weight ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited